@@ -39,10 +39,6 @@ class InstanceTest(testtools.TestCase):
         super(InstanceTest, self).tearDown()
         instances.Instance.__init__ = self.orig__init
 
-    def test___repr__(self):
-        self.instance.name = "instance-1"
-        self.assertEqual('<Instance: instance-1>', self.instance.__repr__())
-
     def test_list_databases(self):
         db_list = ['database1', 'database2']
         self.instance.manager.databases = mock.Mock()
@@ -99,7 +95,10 @@ class InstancesTest(testtools.TestCase):
                                         ['db1', 'db2'], ['u1', 'u2'],
                                         datastore="datastore",
                                         datastore_version="datastore-version",
-                                        nics=nics, slave_of='test')
+                                        nics=nics, slave_of='test',
+                                        replica_count=4,
+                                        modules=['mod_id'],
+                                        locality='affinity')
         self.assertEqual("/instances", p)
         self.assertEqual("instance", i)
         self.assertEqual(['db1', 'db2'], b["instance"]["databases"])
@@ -116,6 +115,9 @@ class InstancesTest(testtools.TestCase):
         self.assertEqual('test', b['instance']['replica_of'])
         self.assertNotIn('slave_of', b['instance'])
         self.assertTrue(mock_warn.called)
+        self.assertEqual([{'id': 'mod_id'}], b["instance"]["modules"])
+        self.assertEqual(4, b["instance"]["replica_count"])
+        self.assertEqual('affinity', b["instance"]["locality"])
 
     def test_list(self):
         page_mock = mock.Mock()
